# Set a conventional commit style topic

```
<type>[(optional scope)][!]: <description>
```

feat: what new feature was added
feat!: what breaking change was made
feat(scope): change to scope

# Replace this description with additional information to be included in merge commit

[Conventional Commits](https://www.conventionalcommits.org/en/v1.0.0/)

```
[optional body]

[optional footer(s)]
```

```
More details about the change.

BREAKING CHANGE:
Refs: #{issue}
```
